@@ -16,15 +16,15 @@ from datetime import datetime
 from typing import List
 
 from .literals import (
-    ConnectionState,
-    CustomerGatewayAssociationState,
-    DeviceState,
-    GlobalNetworkState,
-    LinkAssociationState,
-    LinkState,
-    SiteState,
-    TransitGatewayConnectPeerAssociationState,
-    TransitGatewayRegistrationState,
+    ConnectionStateType,
+    CustomerGatewayAssociationStateType,
+    DeviceStateType,
+    GlobalNetworkStateType,
+    LinkAssociationStateType,
+    LinkStateType,
+    SiteStateType,
+    TransitGatewayConnectPeerAssociationStateType,
+    TransitGatewayRegistrationStateType,
 )
 
 if sys.version_info >= (3, 8):
@@ -138,7 +138,7 @@ ConnectionTypeDef = TypedDict(
         "ConnectedLinkId": str,
         "Description": str,
         "CreatedAt": datetime,
-        "State": ConnectionState,
+        "State": ConnectionStateType,
         "Tags": List["TagTypeDef"],
     },
     total=False,
@@ -191,7 +191,7 @@ CustomerGatewayAssociationTypeDef = TypedDict(
         "GlobalNetworkId": str,
         "DeviceId": str,
         "LinkId": str,
-        "State": CustomerGatewayAssociationState,
+        "State": CustomerGatewayAssociationStateType,
     },
     total=False,
 )
@@ -268,7 +268,7 @@ DeviceTypeDef = TypedDict(
         "Location": "LocationTypeDef",
         "SiteId": str,
         "CreatedAt": datetime,
-        "State": DeviceState,
+        "State": DeviceStateType,
         "Tags": List["TagTypeDef"],
     },
     total=False,
@@ -379,7 +379,7 @@ GlobalNetworkTypeDef = TypedDict(
         "GlobalNetworkArn": str,
         "Description": str,
         "CreatedAt": datetime,
-        "State": GlobalNetworkState,
+        "State": GlobalNetworkStateType,
         "Tags": List["TagTypeDef"],
     },
     total=False,
@@ -391,7 +391,7 @@ LinkAssociationTypeDef = TypedDict(
         "GlobalNetworkId": str,
         "DeviceId": str,
         "LinkId": str,
-        "LinkAssociationState": LinkAssociationState,
+        "LinkAssociationState": LinkAssociationStateType,
     },
     total=False,
 )
@@ -408,7 +408,7 @@ LinkTypeDef = TypedDict(
         "Bandwidth": "BandwidthTypeDef",
         "Provider": str,
         "CreatedAt": datetime,
-        "State": LinkState,
+        "State": LinkStateType,
         "Tags": List["TagTypeDef"],
     },
     total=False,
@@ -459,7 +459,7 @@ SiteTypeDef = TypedDict(
         "Description": str,
         "Location": "LocationTypeDef",
         "CreatedAt": datetime,
-        "State": SiteState,
+        "State": SiteStateType,
         "Tags": List["TagTypeDef"],
     },
     total=False,
@@ -481,7 +481,7 @@ TransitGatewayConnectPeerAssociationTypeDef = TypedDict(
         "GlobalNetworkId": str,
         "DeviceId": str,
         "LinkId": str,
-        "State": TransitGatewayConnectPeerAssociationState,
+        "State": TransitGatewayConnectPeerAssociationStateType,
     },
     total=False,
 )
@@ -489,7 +489,7 @@ TransitGatewayConnectPeerAssociationTypeDef = TypedDict(
 TransitGatewayRegistrationStateReasonTypeDef = TypedDict(
     "TransitGatewayRegistrationStateReasonTypeDef",
     {
-        "Code": TransitGatewayRegistrationState,
+        "Code": TransitGatewayRegistrationStateType,
         "Message": str,
     },
     total=False,
